import json
import sys
import requests
import os

def post(authtoken, content, filename):
    print("Uploading " + filename)
    if len(sys.argv) == 3:
        filepath = os.path.basename(sys.argv[2]).strip("\n")
    else:
        filepath = filename
    jsondata = "{\"files\": {\""+filepath+"\": {\"content\": \""+content+"\"}}}"
    header = {'User-Agent': "pygisty", "Authorization": "token "+authtoken, "Accept": "application/json"}
    r = requests.Session()
    r.headers.update(header)
    request = r.post("https://api.github.com/gists", data=jsondata.encode(encoding='utf-8'))
    dat = json.loads(request.text)
    try:
        error = dat["message"]
        print("Error: " + error)
        sys.exit(1)
    except KeyError:
        test = ""
    html = dat["html_url"]
    return html



from pygisty.gisty import version
import sys
def options(args):
    if args == "--help" or args == "-h":
        print("pygisty help")
        print("-f, --file <filename> Uploads the content of the file to the gist.")
        print("-v, --version Prints the program's version")
        print("-h, --help Prints help")
        sys.exit(0)
    if args == "--version" or args == "-v":
        print("pygisty v"+version.version())
        sys.exit(0)
    if args == "--file" or args == "-f":
        print("No file provided. Exiting.")
        sys.exit(1)
    if "--" or "-" in args:
        print("Invalid options. Exiting")
        sys.exit(1)
def fileoptions(file, args):
    if args == "--file" or args == "-f":
        with open(file, "r") as file:
            data = file.read().replace("\n", "\\n").replace("\"", "\\\"")
        return data
